createEmptyInstance method
Creates an empty instance of the same message type as this.
Implementation
WsServerMsg createEmptyInstance() => create();
Creates an empty instance of the same message type as this.
WsServerMsg createEmptyInstance() => create();